#
# spec file for package rocksndiamonds
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rocksndiamonds
Version:        4.3.8.2
Release:        1.1
Summary:        Colorful Boulderdash'n'Emerald Mine'n'Sokoban'n'Stuff
License:        GPL-2.0-or-later
Group:          Amusements/Games/Action/Arcade
URL:            https://www.artsoft.org/rocksndiamonds/
Source0:        https://www.artsoft.org/RELEASES/linux/%{name}/%{name}-%{version}-linux.tar.gz
Source1:        %{name}-icons.tar.gz
Source2:        %{name}.desktop
# PATCH-FIX-UPSTREAM Permissions
Patch0:         %{name}-src_libgame_setup.c-CVE-2011-4606.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  system-user-games
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(zlib)
Requires:       %{name}-data
Requires(pre):  user(games)

%description
This is a nice little game with color graphics and sound for your Unix system
with color X11.  You need an 8-Bit color display or better.  It will not work
on black&white systems, and maybe not on gray scale systems.

If you know the game Boulder Dash (Commodore C64) or Emerald Mine (Amiga),
you know what Rocks'n'Diamonds is about.

%prep
%autosetup -p1 -b1

# Remove not needed files
find levels -name '*.orig' -delete
rm -f %{name}

%build
%make_build \
    OPTIONS="%{optflags}" \
    RO_GAME_DIR=%{_datadir}/%{name} \
    RW_GAME_DIR=%{_localstatedir}/games/%{name}

%install
# install executable
install -Dm 0755 %{name} %{buildroot}%{_bindir}/%{name}

# install directories
mkdir -p %{buildroot}%{_datadir}/%{name}/{graphics,levels,music,sounds}
for d in graphics levels music sounds ; do
    cp -a $d %{buildroot}%{_datadir}/%{name}
done

# install icons
for i in 32 48 64 72 96 ; do
    install -Dm 0644 ../icons/%{name}_${i}x${i}.png \
            %{buildroot}/%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

# install desktop file
install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop

install -Dm 755 -d %{buildroot}%{_localstatedir}/games/%{name}

%suse_update_desktop_file %{name}

%fdupes -s %{buildroot}%{_prefix}

%files
%license COPYING
%doc CREDITS ChangeLog
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/%{name}
%attr(0775,games,games) %{_localstatedir}/games/%{name}

%changelog
* Sun Apr  7 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 4.3.8.2:
  * fixed drawing pause button on closed door when restarting paused game
  * added optional button to restart game (door, panel and touch variants)
* Tue Jan 30 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 4.3.8.1:
  * changed setup option to disable global animations to only affect toons
  * fixed bug caused by support for only eight global animations in the past
  * fixed correctly using defined draw order of global animations
  * fixed always drawing pointer-style global animations above everything else
  * fixed bug with closing doors when exiting from level editor
* Wed Dec 20 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 4.3.8.0:
  * added random push delay for rocks, nuts and bombs to Emerald Mine game engine
  * added support for fading in and fading out global animations
  * added support for setting alpha value for global animations
  * added support for setting alpha value for envelope style request dialogs
  * added showing game actions after game end when request dialog opens/closes
  * fixed bug with invisible envelope request if request background is masked
  * fixed using masked elements when using element graphic for empty space
  * fixed bug with loading artwork if only one “special” artwork set exists
  * fixed various bugs and problems with global animations (thanks, Eizzoux!)
- Update to version 4.3.7.0:
  * added highlighting similar elements in editor when pressing Alt+Shift keys
  * added highlighting single MM wall tiles in editor when pressing Alt key
  * added options “played_header” and “played” to music file info
  * added support for custom elements triggering global animations
  * added support for CE change pages triggering global animations
  * added setting global animation position from CE triggering that animation
  * added option to not trigger further animations if CE change event consumed
  * added pausing global animations on playfield if game engine is paused
  * added new animation mode “level_nr” to select frame according to level
  * added selecting element for group elements according to current level
  * added options “game.forced_scroll_x” and “game.forced_scroll_y”
  * fixed drawing (maybe redefined) empty space around MM style level in editor
  * fixed crash bug on info screen if music set has no unconfigured music
  * fixed bugs when using music sets without unconfigured game music
  * fixed broken animation of CE that can not change, but has CE delay action
  * fixed bug with checking for mouse events used by custom elements
  * fixed playfield redraw bug when closing envelope after asking to play again
  * fixed setting global animation sync frame when started with “.init_event”
  * fixed one-frame delay when global animations leave “init” state
  * fixed CE condition that checks touching the player at some side
  * fixed drawing envelope request to be always on top of tile cursor
  * fixed drawing envelope request to be always on top of global animations
  * fixed bug with CE change setting the player to its current position
  * fixed bug with CE replacing exploding player, causing half-dead player
  * fixed broken player option “no centering when relocating”
  * fixed half-tile shifting when teleporting between playfield borders
  * fixed bug with using wrong global border when restarting the game
* Mon Jul  3 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 4.3.6.0:
  * added new Deflektor style steel slope game elements for MM game engine
  * added new Deflektor style fixed mirror game elements for MM game engine
  * added flipping and rotating brushes in level editor using keys “x”, “y” and “z”
  * added supporting reference elements for custom element explosion content
  * improved showing game music on music info screen
  * fixed bug with playing game music for first level of level set
  * fixed centering credits text when using fonts with different width
  * fixed drawing mouse pointer global animation above MM engine tile cursor
  * fixed bug with triggering “entered by player” event when pushing element
- Update to version 4.3.5.0:
  * improved Mirror Magic graphics engine to support more custom graphics
  * added new animations for some game elements in Mirror Magic game engine
  * added customizability of gray ball content for Mirror Magic game engine
  * added support for text envelope elements for the Mirror Magic game engine
  * added support for “stacked” global animations
  * fixed a lot of bugs and problems in the Mirror Magic game engine
  * fixed bug with broken graphics when pushing elements into explosions
  * fixed potential crash bug when running in headless mode
  * fixed regression bug with growing steel wall turning into normal wall
  * fixed bug with not scaling images despite using option “.scale_up_factor”
  * changed logging to write to one single log file “rocksndiamonds.log”
- compressed icons to save some space
* Tue Jan 24 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 4.3.4.0:
  * added optional main menu button to directly show level set info
  * added new, topic-related headlines for info screens
  * added support for separate sound and music for info sub-screens
  * added third tutorial level set “ncrtorial” by ncrecc
  * improved some game element graphics in the level editor
  * fixed some bugs
- Changes in version 4.3.30:
  * added showing score even if not added to local score file
  * added CSS to fill browser window for Emscripten (browser) platform
  * added support for “Home” and “End” keys to text gadgets
  * added using setup option for displaying overlay touch buttons
  * added level info config option to disable time limit for all levels
  * added asking for uploading remaining tapes when enabling score server
  * added alpha channel for anti-aliasing to element collecting image
  * added command line option to select display to open program window on
  * added resizing window instead of recreating it on window size changes
  * added new animation mode “.global_anim_sync” for game element graphics
  * added support for custom graphics for many elements of MM game engine
  * added project files for Windows and Mac platforms
  * added quality improved sound and music samples
  * added support for multiple pages (files) for level set info
  * added drawing sparkles when laser hits mirrors for MM engine
  * added pausing tape after replaying not only for warp mode
  * added setup option to continue recording after replaying tape
  * fixed bug with leaving scores screen on Android platform
  * fixed continuing from hall of fame after playing on Android platform
  * fixed bug with broken text area content when editing envelope text
  * fixed synchronization problem when configuring game controller
  * fixed synchronization problem when configuring keyboard
  * fixed bug when using different normal and deadly shield time
  * fixed crash bugs when accessing invalid data in broken level files
  * fixed code issues found by Cppcheck (static C/C++ code analysis tool)
  * fixed code issues found by Clang with option “-fsanitize=undefined”
  * fixed code issues found by GCC with option “-Wextra”
  * fixed some bugs with tape handling
  * Rebase rocksndiamonds-src_libgame_setup.c-CVE-2011-4606.patch
* Thu May 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.3.2.1:
  + The most important feature of this new release version is a new
    screen in the “Hall of Fame” that shows some more details for
    each score entry, together with the possibility to replay the
    tapes for each score, which are loaded from the score server.
* Tue May  4 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.2.3.1
  * added “last played level sets” sub-menu to level set selection
    screen
  * added step delay option to custom element movement configuration
  * added support for left, middle or right mouse button for
    CE change events
  * added setup option to disable counting score after the game
  * added setup options to disable asking on quit game and on
    quit program
  * added graphics config option to support elements on non-black
    background; this feature can be activated by using
    “game.use_masked_elements: true” in the custom graphics
    configuration file
  * changed custom artwork list to tree structure similar to level
    sets, which is separated into three sub-trees for standalone
    artwork
  * changed sorting and coloring in level sets menu and custom
    artwork menu
  * changed saving back artwork info cache only if it has changed
  * fixed two nasty bugs that could have crashed the game
* Sat Jan 23 2021 Dirk Müller <dmueller@suse.com>
- don't recreate games user - managed by systemd-users-game
- update to 4.2.2.1:
  * fixed bug with playing team mode tapes with changed visible playfield size
  * added patch mode to patch tapes to force visible playfield size of 34 x 34
  * added patch mode to automatically fix tapes for visible playfield size
  * fixed single step mode for R’n’D game engine when used in team mode
  * fixed triggering custom element actions by digging or collecting
  * added option in level editor to use time score for 1 or 10 seconds left
  * fixed time score for native Emerald Mine and Diamond Caves levels
  * fixed bug with screen keyboard still being active during request dialogs
  * fixed bug with screen keyboard causing overlay buttons to be disabled
  * added option to disable warning about read-only levels when entering editor
  * fixed bug with not updating game panel when leaving invisible warp mode
  * fixed displaying new high score entry if new entry is not on the first page
  * fixed graphical bug with envelope style request dialog after the game ended
* Sun Jan  3 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to 4.2.2.0
  * added showing as many keys as possible in the default game panel
  * added setup option to show dynamite and keys for the Emerald
    Mine collection
  * added support for improved display of keys for the Emerald
    Mine collection
  * added support for improved request dialog in Emerald Mine
    collection
  * fixed graphical glitch in some cases after request dialog if
    game has ended
  * fixed delayed processing of input event immediately after game
    has started
  * fixed “empty first move” in step pause mode with Emerald Mine
    game engine
  * Visit https://www.artsoft.org/rocksndiamonds/ for the complete
    changelog.
- Update to 4.2.1.0
  * added highlighting of drawing element to level editor when
    pressing “Alt” key
  * added support for using and switching between multiple players
    or teams
  * added player/team selection screen when clicking on player
    name in main menu
  * fixed bug with unnecessarily reloading custom artwork on
    ECS/AGA change
- Update to 4.2.0.5
  * fixed handling of player at fake acid for EM engine
  * fixed wrap-around with entering EM style doors for EM engine
  * fixed activating robot wheel at wrap-around position for EM
    engine
  * fixed some elements and properties when reading native DC2
    levels
  * added Emscripten support for running R’n’D in a web browser
  * fixed compiling on OS/2 (ArcaOS, in fact)
  * fixed some compiler warnings for newer versions of GCC
- Rebase und rename half-upstreamed from
  rocksndiamonds-3.3.1.2-src_libgame_setup.c-CVE-2011-4606.patch
  to rocksndiamonds-src_libgame_setup.c-CVE-2011-4606.patch
* Thu Nov  5 2020 Markus Beth <markus.beth@web.de>
- Update to 4.2.0.3
  * fixed some problems with wrap-around levels in Emerald Mine engine
  * added full compatibility for wrap-around levels in Emerald Mine engine
  * fixed single-step mode for wrap-around levels in Emerald Mine engine
  * fixed playing tapes recorded with old Emerald Mine game engine
  * added command “autofix” to fix tapes recorded with old EM game engine
  * fixed key shortcut to start/end game (which was broken since 4.2.0.0)
  * fixed some other key shortcuts that require entering upper case letters
  * added menu command “:undo-tape” to undo/restore last recorded tape
  * fixed potential crash bug that may occur when loading custom artwork
  * fixed single-step mode when using custom elements with mouse click events
  * added creating undo/redo snapshots when using mouse click events
  * fixed problems with virtual buttons and showing envelopes on Android
  * improved startup speed by optimizing parsing of parameter values
  * improved handling output of warnings, errors and debug messages
  * fixed showing source date on version page of info screen menu
  * added showing commit hash on version page of info screen menu
  * fixed broken tapes (for various reasons) recorded with old EM engine
  * fixed support for initially moving spring in EM game engine
  * added support for initially moving spring to R’n’D game engine
  * fixed potential crash bug when reading from artwork info cache
  * fixed wrong eater content when loading native EM levels
  * added support for variable number of eater arrays for EM engine
  * fixed vsync mode when not using OpenGL renderer (like “Metal” on Mac)
  * added option for setting hint for render driver to setup config file
  * added displaying render driver on info screen page
  * fixed loading dynamic libraries shipped with the Linux package
  * fixed level editor key shortcuts (broken by regression)
  * fixed support for wrap-around levels in EM engine for old tapes
  Visit https://www.artsoft.org/rocksndiamonds/ for the complete
  changelog.
* Mon Mar 30 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.1.4.1
  * fixed bug in editor with group elements using graphic of
    other element
  * fixed crash bug when loading graphics sets with bad
    animation definitions
  * fixed bug in editor with custom elements using graphic
    of other element
  * removed support for SDL 1.2
  Visit https://www.artsoft.org/rocksndiamonds/ for the complete
  changelog.
* Sun Dec 23 2018 Sebastien CHAVAUX <seb95.scou@gmail.com>
- Update to version 4.1.1.0
  * improved support for network multi-player games
  * network games can now be fully configured by using setup menu
  settings
  * when playing network games, the level to be played is now sent
  to all clients
  * added UDP broadcast to auto-detect network server in local
  network
  * multi-player levels now marked in main menu preview with
  network or team mode
  * fixed team mode games in R’n’D game engine
  * added player option in level editor to let the first player
  solve the level
  * improved support for highly configurable virtual buttons on
  touch devices
  * options for transparency, grid size, highlighted and outlined
  virtual buttons
  * separately configurable virtual buttons for portrait and
  landscape mode
  * ultra-smooth scrolling using vertical sync (vsync) on
  supported devices
  * added setup option to directly play the next level after
  solving a level
  * added setup option to skip displaying the high scores after
  solving a level
  * added setup option to use extended list for game speed
  selection
  * added event actions (key events and screen buttons) to global
  animations
  * this allows for simulating key or button events when
  animations are clicked
  * added “passthrough” option to click several overlapping global
  animations
  * fixed bug with dragon fire destroying indestructible steel
  letter walls
  * fixed various other bugs (and probably added some new)
* Mon Jul 23 2018 bwiedemann@suse.com
- Update to version 4.1.0.0
  - Drop upstreamed reproducible.patch
  - Rebase half-upstreamed rocksndiamonds-3.3.1.2-src_libgame_setup.c-CVE-2011-4606.patch
  - many fixes and improvements
* Thu Mar 30 2017 meissner@suse.com
- require system user and group games on new distros,
  useradd and groupadd on older ones.
* Thu Apr  7 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare
* Fri Oct 10 2014 nemysis@gmx.ch
- Add because are added or deleted patches
* Wed Oct  8 2014 nemysis@gmx.ch
- Remove BuildRequires for libsmpeg-devel and add sed,
  because is unresolvable
- Use BuildRequires pkgconfig(SDL_image), pkgconfig(SDL_mixer),
  pkgconfig(SDL_net) instead of SDL_image-devel, SDL_mixer-devel,
  SDL_net-devel
- Remove PreReq for shadow and pwdutils
* Tue Oct  7 2014 nemysis@gmx.ch
- Changed .changes and used old entries from somebody else
- Update to 3.3.1.2, announce message:
  - fixed bug that prevents running the game on Mac OS X "Mavericks"
  - improved behaviour on restart after failing on a broken level set
  - Message for 3.3.1.1 update
  * added scripts directory to distribution package to enable building
    element definitions after editing artwork config source code files
  * added volume controls for sounds, loops and music to sound setup
  Most important changes since last release version 3.3.0.1:
  - added native package for Macs with intel CPUs
  - added support for compiling on 64-bit systems
  - added alternative game mode for playing with half size playfield tiles
  - added level selection screen (when clicking on main menu level number)
  - added displaying if level was played or solved on level selection screen
  - improved graphics performance for scrolling in Mac OS X version
  - improved graphics performance for native Supaplex game engine
  - improved single step mode in R'n'D, EM and SP engines
  - fixed two game engine bugs in Supaplex game engine
  - fixed displaying wrong Supaplex time (was running too fast before)
  - fixed invisible text in envelope config in level editor
- Use check for openSUSE > 12.2 for and use shadow else pwdutils
- Add PreReq for shadow (was removed pwdutils)
- Change %%fdupes
- Change Desktop entry file
- Change Summary
- Removed Contributions-1.2.0.tar.bz2 and move to new package
  rocksndiamonds-data
- Use simple sed instead of rocksndiamonds-3.3.0.1-smpeg.patch
- Use rocksndiamonds-3.3.1.2-src_libgame_setup.c-CVE-2011-4606.patch
  instead of rocksndiamonds-CVE-2011-4606.patch, upstream still has
  not patched the security problem themselves
- Add BuildRequires for libsmpeg-devel
- Use %%{name}-icons.tar instead of %%{name}.png
- Add BuildRequires for hicolor-icon-theme
- Remove BuildRequires for deprecated pwdutils
- Add Requires for %%{name}-data
- Change description
- Simplify installation handling
- Remove not needed files
* Mon Sep 23 2013 idonmez@suse.com
- Add games user/group on demand (fate#314560)
* Sat Jan 26 2013 joop.boonen@opensuse.org
- Dropped all permission scripts
* Thu Jan 24 2013 joop.boonen@opensuse.org
- run_permissions was replaced by set_permissions
  http://en.opensuse.org/openSUSE:Packaging_Conventions_RPM_Macros#.25set_permissions
* Fri Jan 18 2013 joop.boonen@opensuse.org
- run_permissions is obsolete, not supported in openSUSE > 12.2
- cleaned the spec file up
* Fri Jul 13 2012 meissner@suse.com
- do not create ~/.rocksndiamonds/ world writeable.
  bnc#736261 / CVE-2011-4606
* Fri Mar 23 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant sections/tags
* Sun Apr 24 2011 PVince81@opensuse.org
- updated to version 3.3.0.1
- moved game data to /usr/share instead of /usr/share/games
  according to packaging conventions
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Oct 31 2008 meissner@suse.de
- run fdupes
* Wed Mar  5 2008 anosek@suse.cz
- updated to version 3.2.4
  * lots of improvements and bugfixes. See ChangeLog for the full list
  * title messages are now also searched in graphics artwork directory;
  those found in graphics directory have precendence over those found
  in level directory -- this handles title messages stored in graphics
  directories as part of the artwork set, just like title images; this
  makes sense, as corresponding special font definitions for messages
  are usually defined in the same graphics artwork directory, and also
  because title images and title messages that are combined in a level
  set introduction should usually not be separated when the level set
  is used with a different artwork set (e.g. using "override graphics")
  * added use of hashes created from static lists (element tokens, image
  config, font tokens) to speed up lookup of configuration parameters
  * added "busy" animation when initializing program and loading artwork
  * added initialization profiling for program startup (debugging only)
  * added graphics engine directive "border.draw_masked_when_fading" that
  enables/disables drawing of border mask over screen that is just faded
  * added additional configuration directives for setup screen draw offset
  menu.draw_xoffset.SETUP[XXX] and menu.draw_yoffset.SETUP[XXX] with XXX
  in GAME, EDITOR, GRAPHICS, SOUND, ARTWORK, INPUT, SHORTCUTS_1,
  SHORTCUTS_2, CHOOSE_ARTWORK, CHOOSE_OTHER (where "CHOOSE_ARTWORK" is
  used to define draw offset on custom artwork selection screens and
  "CHOOSE_OTHER" is used on all other list style selection screens, like
  choosing game speed or screen mode for fullscreen mode)
  * added eight pure decoration graphic definitions for the game panel
  * added support for accessing native Diamond Caves II level packages
  * added game panel control to display arbitrary elements on game panel
  * added game panel control to display custom element score (globally
  unique for identical custom elements) either as value or as element
  * added ".draw_masked" and ".draw_order" to game panel control drawing
  * added displaying of gravity state (on/off) as new game panel control
  * added animation for game panel elements (similar to game elements)
  * added new pseudo game mode "PANEL" to define panel fonts and graphics
  - panel fonts now use ".PANEL" suffix instead of ".PLAYING" suffix
  - panel graphics now use ".PANEL" suffix instead of ".DOOR" suffix
  (else graphics would have to use ".PLAYING", which would be confusing)
  * added attribute ".tile_size" for element style game panel controls
  * added <space> key as additional valid key to use for confirm requester
  * improved menu fading, adding separate fading definitions for entering
  and leaving a "content" screen (in general), and optional definitions
  for the special "content" screens SCORES, EDITOR, INFO and PLAYING
  * added (currently invisible) setup option to define scroll delay value
  * added option "game.forced_scroll_delay_value" to override user choice
  of scroll delay value for certain level sets with "graphicsinfo.conf"
  * replaced setup option "scroll delay: on/off" by new setup option that
  directly allows selecting the desired scroll delay value from 0 to 8
  * added displaying of most game panel control elements (not animated)
  * added new configuration directives to display additional game engine
  values on the game control panel, like the following examples:
  - game.panel.time_hh/time_mm/time_ss	- level time in HH/MM/SS format
  - game.panel.penguins			- number of penguins to rescue
  - game.panel.level_name		- level name of current level
  * added support for preview tile sizes "1" and "2" (1x1 and 2x2 pixels)
  * added new player option "no centering when relocating" for "invisible"
  teleportations to level areas that look exactly the same, giving the
  illusion that the player did not relocate at all (this was the default
  since 3.2.3, but caused visual problems with room creation in "Zelda")
  * added new menu fading effect "melt", shamelessly stolen from "DOOM"
  * improved menu fading, adding separate fading definitions for entering
  and leaving a menu and for fading between menu and "content" screens
  * improved menu fading, adding separate fading definitions for fading
  between menu screens and fading between menu and "destination" screens
  * titlemessage_initial_x and titlemessage_x set to "[DEFAULT]" in static
  configuration (set from "[titlemessage_initial]" and "[titlemessage]")
  * fading settings of "[titlemessage_initial]" and "[titlemessage]" set
  to "[DEFAULT]" in static configuration (set from "[title_initial]" and
  "[title]")
  * improved title fading, allowing fading animation types "none", "fade"
  and "crossfade" (including cross-fading of last title to main menu)
  .......
* Sat May 19 2007 coolo@suse.de
- remove X-SuSE-translate from desktop file
* Mon Mar  5 2007 ssommer@suse.de
- BuildRequires SDL_net-devel
* Mon Feb  5 2007 anosek@suse.cz
- updated to version 3.2.3
  * bugfix release
  * some improvements on program startup performance
* Mon Sep 11 2006 anosek@suse.cz
- updated to version 3.2.2
  - instant tape reloading for the last saved tape using "quick save/load"
  - fixed bug that prevented solving levels without exit (like in Sokoban)
  - fixed bug with quick loading tapes in fullscreen with EMC game engine
  - fixed level time for EMC levels (needed for the upcoming EMC collection)
  - added key shortcut "Alt + Enter" to toggle fullscreen mode at any time
  - added support for mouse scroll wheel for all scrollbar gadgets
  - added support for horizontal mouse wheel scrolling by holding "Shift"
  - added support for single step mouse wheel scrolling by holding "Alt"
  - improved down-scaling of images for better editor and preview graphics
* Thu Aug  3 2006 anosek@suse.cz
- updated to version 3.2.0
  - finished new native game engine for Emerald Mine (Club) levels
  - added all new elements from EMC engine also to R'n'D engine
  - added selection between ECS and AGA graphics for EMC levels to setup
  - added multi-player support for EMC game engine (with up to four players)
  - added player switching (visual and quick) to R'n'D and EM game engine
  - added key shortcut settings for switching player focus to setup menu
  - added custom element actions for CE change page in level editor
  - added "CE value" and "CE score" counters for custom elements
  - added cascaded element lists to element list in level editor
  - added dynamic element list with all elements used in current level
  - added special Supaplex animations for Murphy being bored and sleeping
  - added setup option to display element token name in level editor
  - added up to five title screens for each level set to show after loading
  - added credits pages to the "credits" section that were really missing
  - lots of bugfixes and internal engine changes (see ChangeLog file)
- dropped obsolete patches
  rocksndiamonds-3.1.1-overflow.patch
  rocksndiamonds-3.1.1-userlevels.patch
* Wed Feb  1 2006 mmarek@suse.cz
- fix user levels being readonly after last update
  (userlevels.patch) (patch from upstream)
* Tue Jan 31 2006 mmarek@suse.cz
- fix buffer overflow reported by David Binderman
  [#146444] (overflow.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 mmarek@suse.cz
- added contributed levels
- added icon
* Mon Dec 19 2005 mmarek@suse.cz
- updated to 3.1.1
* Tue Apr 12 2005 mcihar@suse.cz
- fix for gcc 4
* Mon Jan 31 2005 ro@suse.de
- fix build
* Wed Aug  4 2004 mcihar@suse.cz
- update to 3.1.0
* Fri Mar 19 2004 mcihar@suse.cz
- remove *.orig files
* Wed Mar  3 2004 mcihar@suse.cz
- update to 3.0.8
* Wed Oct 29 2003 mcihar@suse.cz
- package according to permissions.secure and add %%run_permissions
- no root for build
* Tue Oct 14 2003 mcihar@suse.cz
- install in /usr/games and /usr/share/games
- update to 3.0.6 (mostly bugfixes)
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Thu Aug  7 2003 mcihar@suse.cz
- updated to 3.0.0:
  - graphics and sounds now completely and dynamically customizable
  - element animation length, speed and mode now freely configurable
  - 128 custom elements with lots of configurable element properties
  - advanced custom element settings for powerful, self-created elements
  - automatic tape playing function for game engine and level testing
  - added support for stereo WAV sound files
  - added support for background images for all menu screens
  - added some example levels showing how to create custom artwork
  - fixed Supaplex gravity tubes
  - fixed very nasty bug in SDL_image (and X11) PCX loading routine
  - fixed some very nasty bugs in bitmap zoom routine
  - fixed very nasty bug in level/artwork loading routine
- no more patches needed
- SDL version is being built now
* Thu Feb  6 2003 mcihar@suse.cz
- updated to 2.1.1:
  - sound bug (causing crashes) fixed (reported by Keith Peterston)
  - support for /dev/sound/dsp (devfs) added (thanks to Christoph Bauer)
  - added new contributed levels from the following players:
    + Alan Bond
    + Gerrit Holl
* Tue Aug  6 2002 mcihar@suse.cz
- updated to 2.1.0:
  - graphics, sounds and music now fully configurable
  - added support for TrueColor PCX graphics files
  - added support for 16 bit WAV sound files
  - enhanced sound system (especially regarding stereo and loop sounds)
  - new structured setup menu (with sub-menues for graphics and sounds)
  - added "quick save" and "quick load" functions with shortcut key
  - added single-step playing mode (automatic pause after each step)
  - behaviour of "Escape" key in level editor now more intuitive
  - changed default slipping behaviour of gems back to 2.0.0 style;
  this is now an element property for gems in the level editor,
  although existing converted levels use the new EM gems behaviour
  - bug fixed that prevented walking through tubes when gravity on
  - added Boulder Dash style "snap-pushing" (thanks to Achim Haertel)
  - fixed memory leak in image loading code
  - fixed some "solid" elements that were accidentally destructible
  - fixed some tape stuff
  - added new contributed levels and graphics from players
* Sun Aug  4 2002 ro@suse.de
- group name changed "game" -> "games"
* Tue Jun 11 2002 mcihar@suse.cz
- updated to 2.0.1
  - bug in explosion code fixed that broke level 24 of "Baby Ghost Mine"
  - several Supaplex emulation bugs fixed (thanks to Mihail Milushev):
  - behaviour of robots adjusted to make them less aggressive
  - bug when selecting default level series fixed
  - new IFF style file format for level and tape files
  - bug in storing amoeba content fixed
  - nasty tape bugs fixed (completely reworked tape stuff)
  - file permissions when saving files and creating directories changed
  - some small sound bugs fixed
  - added new contributed levels
* Thu Jan 10 2002 cihlar@suse.cz
- use %%{_lib}
* Wed Sep 19 2001 ro@suse.de
- unified changelog
* Mon Mar 12 2001 cihlar@suse.cz
- fixed to compile on axp
* Thu Mar  8 2001 cihlar@suse.cz
- update to version 2.0.0
* Thu Feb  8 2001 cihlar@suse.cz
- fixed to compile
* Fri Dec  8 2000 cihlar@suse.cz
- added missing levels
* Fri Dec  1 2000 cihlar@suse.cz
- again fixed file permissions
* Wed Nov 15 2000 cihlar@suse.cz
- renamed rockdiam -> rocksndiamonds
- clean up spec file
- fixed file permissions
* Tue Apr 18 2000 cihlar@suse.cz
- upgrade to version 1.4.0
- added BuildRoot
* Sun Mar  5 2000 olh@suse.de
- move manpages
* Mon Jan 31 2000 uli@suse.de
- fixed misuse of va_arg macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Mar 12 1999 uli@suse.de
- update 0.9b -> 1.3.0
- eliminated Makefile.Linux
* Mon Oct 20 1997 hf@suse.de
- ready for autobuild
* Mon Jun  9 1997 hf@suse.de
- Changing the permissions for the highscorefiles.
* Fri Jun  6 1997 hf@suse.de
- Changing the permissions for the highscoredirectory.
* Mon May  5 1997 hf@suse.de
- The binary rocksndiamonds has the sgid game
  for edit the highscore and name files.
* Thu Mar  6 1997 hf@suse.de
- Version 0.9
  Anpassungen im Makefile, zusaetzliche defines angelegt
